{% extends "epic/base_layout.html" %}

{% block content %}

<div class="alert alert-danger" style="margin:12px">
  {% for msg in messages %}
  {{ msg|safe }}
  <br>
  {% endfor %}
</div>

 <div class="row">
   <div>
     <a class="btn btn-default"
	href="{{ parent_url }}">
       OK <i class="glyphicon glyphicon-chevron-ok"></i>
     </a>
   </div>
 </div>

{% endblock content %}
